Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(392)

Unified Diff: third_party/WebKit/Source/bindings/tests/results/core/V8TestObject.cpp

Issue 2691333002: Replace [CallWith=ExecutionContext] with [CallWith=ScriptState] (Closed)
Patch Set: Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/bindings/tests/results/core/V8TestObject.cpp
diff --git a/third_party/WebKit/Source/bindings/tests/results/core/V8TestObject.cpp b/third_party/WebKit/Source/bindings/tests/results/core/V8TestObject.cpp
index 8ce4788307f64c43583bdc8be0ac4cd3fd501abb..18b1c3253e3bebdba3b2ae1e58f8d13f84e542c8 100644
--- a/third_party/WebKit/Source/bindings/tests/results/core/V8TestObject.cpp
+++ b/third_party/WebKit/Source/bindings/tests/results/core/V8TestObject.cpp
@@ -7696,9 +7696,9 @@ static void postMessageImpl(const char* interfaceName, TestObject* instance, con
return;
}
- // FIXME: Only pass context/exceptionState if instance really requires it.
- ExecutionContext* context = currentExecutionContext(info.GetIsolate());
- instance->postMessage(context, message.release(), transferables.messagePorts, exceptionState);
+ // FIXME: Only pass scriptState/exceptionState if instance really requires it.
+ ScriptState* scriptState = ScriptState::current(info.GetIsolate());
+ instance->postMessage(scriptState, message.release(), transferables.messagePorts, exceptionState);
}
static void activityLoggingForAllWorldsPerWorldBindingsVoidMethodMethod(const v8::FunctionCallbackInfo<v8::Value>& info) {
« no previous file with comments | « third_party/WebKit/Source/bindings/templates/methods.cpp.tmpl ('k') | third_party/WebKit/Source/core/dom/MessagePort.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698